@@ -2,7 +2,7 @@ from AioPTTCrawler import AioPTTCrawler
 
 def main():
     ptt_crawler = AioPTTCrawler()
-    ptt_crawler.get_board_articles("Gossiping", 100)
+    ptt_crawler.get_board_latest_articles("Gossiping", 100)
 
 
 if __name__ == "__main__":
